Class: Bsdkrun::AiAgent

Inherits:
Data
  • Object
show all
Defined in:
lib/bsdkrun/types.rb

Overview

A coding agent bsdkrun can sandbox.

Each runs in a disposable microVM with a persistent login, a shared skills store, and only the folder you choose to share.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#descriptionObject (readonly)

Returns the value of attribute description

Returns:

  • (Object)

    the current value of description



164
165
166
# File 'lib/bsdkrun/types.rb', line 164

def description
  @description
end

#flavorObject (readonly)

Returns the value of attribute flavor

Returns:

  • (Object)

    the current value of flavor



164
165
166
# File 'lib/bsdkrun/types.rb', line 164

def flavor
  @flavor
end

#idObject (readonly)

Returns the value of attribute id

Returns:

  • (Object)

    the current value of id



164
165
166
# File 'lib/bsdkrun/types.rb', line 164

def id
  @id
end

#installedObject (readonly)

Returns the value of attribute installed

Returns:

  • (Object)

    the current value of installed



164
165
166
# File 'lib/bsdkrun/types.rb', line 164

def installed
  @installed
end

#labelObject (readonly)

Returns the value of attribute label

Returns:

  • (Object)

    the current value of label



164
165
166
# File 'lib/bsdkrun/types.rb', line 164

def label
  @label
end

#runningObject (readonly)

Returns the value of attribute running

Returns:

  • (Object)

    the current value of running



164
165
166
# File 'lib/bsdkrun/types.rb', line 164

def running
  @running
end

Class Method Details

.from_graphql(a) ⇒ AiAgent Also known as: from_row

Parameters:

  • a (Hash)

Returns:



169
170
171
172
173
174
175
176
177
178
# File 'lib/bsdkrun/types.rb', line 169

def self.from_graphql(a)
  new(
    id: a["id"].to_s,
    label: a["label"].to_s,
    flavor: a["flavor"].to_s,
    description: (a["description"] || "").to_s,
    installed: !!a["installed"],
    running: a["running"].to_i
  )
end