Class: Bsdkrun::ShellSessionInfo

Inherits:
Data
  • Object
show all
Defined in:
lib/bsdkrun/types.rb

Overview

An open interactive shell session, as reported by openShell / the shellSessions query. Mirrors +daemon/src/graphql.rs+'s ShellSessionInfo.

Instance Attribute Summary collapse

Instance Attribute Details

#finishedBoolean (readonly)

Returns:

  • (Boolean)


235
# File 'lib/bsdkrun/types.rb', line 235

ShellSessionInfo = Data.define(:id, :machine_id, :finished, :truncated)

#idString (readonly)

Returns:

  • (String)


235
# File 'lib/bsdkrun/types.rb', line 235

ShellSessionInfo = Data.define(:id, :machine_id, :finished, :truncated)

#machine_idString (readonly)

Returns:

  • (String)


235
# File 'lib/bsdkrun/types.rb', line 235

ShellSessionInfo = Data.define(:id, :machine_id, :finished, :truncated)

#truncatedBoolean (readonly)

Returns whether buffered output was dropped to stay under the session buffer cap.

Returns:

  • (Boolean)

    whether buffered output was dropped to stay under the session buffer cap.



235
# File 'lib/bsdkrun/types.rb', line 235

ShellSessionInfo = Data.define(:id, :machine_id, :finished, :truncated)