Class: Bsdkrun::AiAgent
- Inherits:
-
Data
- Object
- Data
- Bsdkrun::AiAgent
- Defined in:
- lib/bsdkrun/types.rb
Overview
A coding agent bsdkrun can sandbox.
Each runs in a disposable microVM with a persistent login, a shared skills store, and only the folder you choose to share.
Instance Attribute Summary collapse
-
#description ⇒ Object
readonly
Returns the value of attribute description.
-
#flavor ⇒ Object
readonly
Returns the value of attribute flavor.
-
#id ⇒ Object
readonly
Returns the value of attribute id.
-
#installed ⇒ Object
readonly
Returns the value of attribute installed.
-
#label ⇒ Object
readonly
Returns the value of attribute label.
-
#running ⇒ Object
readonly
Returns the value of attribute running.
Class Method Summary collapse
- .from_graphql(a) ⇒ AiAgent (also: from_row)
Instance Attribute Details
#description ⇒ Object (readonly)
Returns the value of attribute description
164 165 166 |
# File 'lib/bsdkrun/types.rb', line 164 def description @description end |
#flavor ⇒ Object (readonly)
Returns the value of attribute flavor
164 165 166 |
# File 'lib/bsdkrun/types.rb', line 164 def flavor @flavor end |
#id ⇒ Object (readonly)
Returns the value of attribute id
164 165 166 |
# File 'lib/bsdkrun/types.rb', line 164 def id @id end |
#installed ⇒ Object (readonly)
Returns the value of attribute installed
164 165 166 |
# File 'lib/bsdkrun/types.rb', line 164 def installed @installed end |
#label ⇒ Object (readonly)
Returns the value of attribute label
164 165 166 |
# File 'lib/bsdkrun/types.rb', line 164 def label @label end |
#running ⇒ Object (readonly)
Returns the value of attribute running
164 165 166 |
# File 'lib/bsdkrun/types.rb', line 164 def running @running end |
Class Method Details
.from_graphql(a) ⇒ AiAgent Also known as: from_row
169 170 171 172 173 174 175 176 177 178 |
# File 'lib/bsdkrun/types.rb', line 169 def self.from_graphql(a) new( id: a["id"].to_s, label: a["label"].to_s, flavor: a["flavor"].to_s, description: (a["description"] || "").to_s, installed: !!a["installed"], running: a["running"].to_i ) end |