Class: Bsdkrun::ShellSessionInfo
- Inherits:
-
Data
- Object
- Data
- Bsdkrun::ShellSessionInfo
- Defined in:
- lib/bsdkrun/types.rb
Overview
An open interactive shell session, as reported by openShell / the
shellSessions query. Mirrors +daemon/src/graphql.rs+'s ShellSessionInfo.
Instance Attribute Summary collapse
- #finished ⇒ Boolean readonly
- #id ⇒ String readonly
- #machine_id ⇒ String readonly
-
#truncated ⇒ Boolean
readonly
Whether buffered output was dropped to stay under the session buffer cap.
Instance Attribute Details
#finished ⇒ Boolean (readonly)
235 |
# File 'lib/bsdkrun/types.rb', line 235 ShellSessionInfo = Data.define(:id, :machine_id, :finished, :truncated) |
#id ⇒ String (readonly)
235 |
# File 'lib/bsdkrun/types.rb', line 235 ShellSessionInfo = Data.define(:id, :machine_id, :finished, :truncated) |
#machine_id ⇒ String (readonly)
235 |
# File 'lib/bsdkrun/types.rb', line 235 ShellSessionInfo = Data.define(:id, :machine_id, :finished, :truncated) |
#truncated ⇒ Boolean (readonly)
Returns whether buffered output was dropped to stay under the session buffer cap.
235 |
# File 'lib/bsdkrun/types.rb', line 235 ShellSessionInfo = Data.define(:id, :machine_id, :finished, :truncated) |